import { useState } from "react"
import { useNavigate } from "react-router-dom"
import { enqueueSnackbar } from "notistack"
import {
	Alert,
	Box,
	Button,
	Typography,
	useMediaQuery,
	useTheme,
} from "@mui/material"

import { Loader } from "./Loader"

import { currencyFormatter } from "@root/utils/currencyFormatter"
import { payCart } from "@root/api/cart"
import { setUserAccount } from "@root/stores/user"

interface Props {
  priceBeforeDiscounts: number;
  priceAfterDiscounts: number;
}

export default function TotalPrice({
	priceAfterDiscounts,
	priceBeforeDiscounts,
}: Props) {
	const theme = useTheme()
	const upMd = useMediaQuery(theme.breakpoints.up("md"))
	const isMobile = useMediaQuery(theme.breakpoints.down(550))
	const [notEnoughMoneyAmount, setNotEnoughMoneyAmount] = useState<number>(0)
	const [loading, setLoading] = useState<boolean>(false)
	const navigate = useNavigate()

	async function handlePayClick() {
		setLoading(true)

		const [payCartResponse, payCartError] = await payCart()

		if (payCartError) {
			if (payCartError.includes("insufficient funds: ")) {
				const notEnoughMoneyAmount = parseInt(
					payCartError.replace(/^.*insufficient\sfunds:\s(?=\d+$)/, "")
				)

				setNotEnoughMoneyAmount(notEnoughMoneyAmount)
			}

			setLoading(false)

			return enqueueSnackbar(payCartError)
		}

		if (payCartResponse) {
			setUserAccount(payCartResponse)
		}

		setLoading(false)
	}

	function handleReplenishWallet() {
		navigate("/payment", { state: { notEnoughMoneyAmount } })
	}

	return (
		<Box
			sx={{
				display: "flex",
				flexDirection: upMd ? "row" : "column",
				mt: upMd ? "80px" : "70px",
				pt: upMd ? "30px" : undefined,
				borderTop: upMd ? `1px solid ${theme.palette.gray.dark}` : undefined,
			}}
		>
			<Box
				sx={{
					width: upMd ? "68.5%" : undefined,
					pr: upMd ? "15%" : undefined,
					display: "flex",
					flexWrap: "wrap",
					flexDirection: "column",
				}}
			>
				<Typography variant="h4" mb={upMd ? "18px" : "30px"}>
          Итоговая цена
				</Typography>
				<Typography color={theme.palette.gray.main}>
          Текст-заполнитель — это текст, который имеет Текст-заполнитель — это
          текст, который имеет Текст-заполнитель — это текст, который имеет
          Текст-заполнитель — это текст, который имеет Текст-заполнитель
				</Typography>
			</Box>
			<Box
				sx={{
					color: theme.palette.gray.dark,
					width: upMd ? "31.5%" : undefined,
					pl: upMd ? "33px" : undefined,
				}}
			>
				<Box
					sx={{
						display: "flex",
						flexDirection: upMd ? "column" : "row",
						alignItems: upMd ? "start" : "center",
						mt: upMd ? "10px" : "30px",
						mb: "15px",
						gap: "15px",
					}}
				>
					<Typography variant="oldPrice" sx={{ order: upMd ? 1 : 2 }}>
						{currencyFormatter.format(priceBeforeDiscounts / 100)}
					</Typography>
					<Typography
						variant="price"
						sx={{
							fontWeight: 500,
							fontSize: "26px",
							lineHeight: "31px",
							order: upMd ? 2 : 1,
						}}
					>
						{currencyFormatter.format(priceAfterDiscounts / 100)}
					</Typography>
				</Box>
				{notEnoughMoneyAmount > 0 && (
					<Alert severity="error" variant="filled">
            Нехватает {currencyFormatter.format(notEnoughMoneyAmount / 100)}
					</Alert>
				)}
				<Button
					variant="pena-contained-dark"
					onClick={() =>
						notEnoughMoneyAmount === 0
							? !loading && handlePayClick()
							: handleReplenishWallet()
					}
					sx={{ mt: "10px" }}
				>
					{loading ? (
						<Loader size={24} />
					) : notEnoughMoneyAmount === 0 ? (
						"Оплатить"
					) : (
						"Пополнить"
					)}
				</Button>
			</Box>
		</Box>
	)
}
