import { IconButton, useMediaQuery, useTheme } from "@mui/material"
import { Select } from "@root/components/Select"
import { Box } from "@mui/material"
import { Typography } from "@mui/material"
import { useState } from "react"
import SectionWrapper from "../../components/SectionWrapper"
import AccordionWrapper from "./AccordionWrapper"
import ArrowBackIcon from "@mui/icons-material/ArrowBack"
import { Tabs } from "@root/components/Tabs"
import { useHistoryTracker } from "@root/utils/hooks/useHistoryTracker"

const subPages = ["Pena hub", "Шаблоны", "Опросы", "Ссылки", "Финансовые", "Юридические", "Юридические лица"]

export default function Faq() {
	const theme = useTheme()
	const upMd = useMediaQuery(theme.breakpoints.up("md"))
	const isMobile = useMediaQuery(theme.breakpoints.down(550))
	const isTablet = useMediaQuery(theme.breakpoints.down(1000))
	const [tabIndex, setTabIndex] = useState<number>(0)
	const [selectedItem, setSelectedItem] = useState<number>(0)

	const handleCustomBackNavigation = useHistoryTracker()

	return (
		<SectionWrapper
			maxWidth="lg"
			sx={{
				mt: upMd ? "25px" : "20px",
				px: isTablet ? (isMobile ? "18px" : "40px") : "20px",
				mb: upMd ? "70px" : "37px",
			}}
		>
			<Box
				sx={{
					mt: "20px",
					mb: isTablet ? "38px" : "20px",
					display: "flex",
					alignItems: "center",
					gap: "10px",
				}}
			>
				{isMobile && (
					<IconButton onClick={handleCustomBackNavigation} sx={{ p: 0, height: "28px", width: "28px", color: "black" }}>
						<ArrowBackIcon />
					</IconButton>
				)}
				<Typography
					sx={{
						fontSize: isMobile ? "24px" : "36px",
						fontWeight: "500",
					}}
				>
          Вопросы и ответы
				</Typography>
			</Box>
			<Box sx={{ marginBottom: isMobile ? "20px" : "0px" }}>
				{isMobile ? (
					<Select items={subPages} selectedItem={selectedItem} setSelectedItem={setSelectedItem} />
				) : (
					<Tabs items={subPages} selectedItem={tabIndex} setSelectedItem={setTabIndex} />
				)}
			</Box>

			<TabPanel value={tabIndex} index={0} mt={upMd ? "42px" : "10px"}>
				<AccordionWrapper
					content={[
						[
							"Что такое корзина?",
							"Корзина это место где хранятся выбранные  и собранные вами тарифы,оплатить можно в 1 клик или удалить не актуальные.",
						],
						[
							"Какие функции я могу использовать бесплатно?",
							"Все функции и все продукты, но с ограничением бесплатного периода",
						],
						[
							"Чем могут помочь ваши продукты, конкретно в моём бизнесе?",
							"Вы можете написать в тех поддержку и наши опытные операторы, проконсультируют вас по этому и многим другим вопросам, при наличии таковых.",
						],
						[
							"Можно ли использовать все ваши продукты не имея в штате программиста?",
							"Абсолютно все наши продукты работают по принципу no-code.",
						],
					]}
				/>
			</TabPanel>
			<TabPanel value={tabIndex} index={1} mt={upMd ? "27px" : "10px"}>
				<AccordionWrapper
					content={[
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
					]}
				/>
			</TabPanel>
			<TabPanel value={tabIndex} index={2} mt={upMd ? "27px" : "10px"}>
				<AccordionWrapper
					content={[
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
					]}
				/>
			</TabPanel>
			<TabPanel value={tabIndex} index={3} mt={upMd ? "27px" : "10px"}>
				<AccordionWrapper
					content={[
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
					]}
				/>
			</TabPanel>
			<TabPanel value={tabIndex} index={4} mt={upMd ? "27px" : "10px"}>
				<AccordionWrapper
					content={[
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
					]}
				/>
			</TabPanel>
			<TabPanel value={tabIndex} index={5} mt={upMd ? "27px" : "10px"}>
				<AccordionWrapper
					content={[
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
					]}
				/>
			</TabPanel>
			<TabPanel value={tabIndex} index={6} mt={upMd ? "27px" : "10px"}>
				<AccordionWrapper
					content={[
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
						["Placeholder", "Placeholder"],
					]}
				/>
			</TabPanel>
		</SectionWrapper>
	)
}

interface TabPanelProps {
  index: number;
  value: number;
  children?: React.ReactNode;
  mt: string;
}

function TabPanel({ index, value, children, mt }: TabPanelProps) {
	return (
		<Box hidden={index !== value} sx={{ mt }}>
			{children}
		</Box>
	)
}
