import { useNavigate } from "react-router-dom"
import { useMediaQuery, useTheme, Box, Link, Typography } from "@mui/material"
import SectionWrapper from "@components/SectionWrapper"
import CustomIcon from "@components/icons/CustomIcon"
import CalendarIcon from "@components/icons/CalendarIcon"
import PieChartIcon from "@components/icons/PieChartIcon"
import TariffCard from "./TariffCard"
import WideTemplCard from "@components/wideTemplCard"
import TemplCardPhoneLight from "@components/templCardPhoneLight"

export default function Tariffs() {
	const theme = useTheme()
	const upMd = useMediaQuery(theme.breakpoints.up("md"))
	const isMobile = useMediaQuery(theme.breakpoints.up(550))
	const isTablet = useMediaQuery(theme.breakpoints.down(1000))
	const navigate = useNavigate()

	return (
		<SectionWrapper
			maxWidth="lg"
			sx={{
				mt: upMd ? "60px" : "20px",
				mb: upMd ? "67px" : "75px",
				px: isTablet ? (upMd ? "40px" : "18px") : "20px",
				display: "flex",
				flexDirection: "column",
			}}
		>
			<Typography variant={isMobile ? "h4" : "h5"}>Выберите удобный тариф</Typography>
			<Box
				sx={{
					width: upMd ? "100%" : undefined,
					mt: "40px",
					mb: "30px",
					display: "grid",
					flexWrap: "wrap",
					justifyContent: "center",
					gap: upMd ? "40px" : "30px",
					gridTemplateColumns: `repeat(auto-fit, minmax(300px, ${isTablet ? "439px" : "360px"} ))`,
				}}
			>
				<TariffCard
					icon={<CalendarIcon color="white" bgcolor={theme.palette.purple.main} />}
					headerText="Тарифы на время"
					text="безлимит на 1 месяц , 3 , 6 , 12"
					buttonProps={{
						text: "Подробнее",
						onClick: () => navigate("time"),
					}}
					sx={{ maxWidth: isTablet ? "440px" : "360px" }}
				/>
				<TariffCard
					icon={<PieChartIcon color="white" bgcolor={theme.palette.purple.main} />}
					headerText="Тариф на объем"
					text="200 шаблонов, 1000 шаблонов, 5000 шаблонов, 10 000 шаблонов"
					buttonProps={{
						text: "Подробнее",
						onClick: () => navigate("volume"),
					}}
					sx={{ maxWidth: isTablet ? "440px" : "360px" }}
				/>
				<TariffCard
					icon={<CustomIcon color="white" bgcolor={theme.palette.purple.main} />}
					headerText="Кастом"
					text="Текст-заполнитель — это текст, который имеет "
					buttonProps={{
						text: "Подробнее",
						onClick: () => navigate("/tariffconstructor"),
					}}
					sx={{ maxWidth: isTablet ? "440px" : "360px" }}
				/>
			</Box>
			<Typography component="div">
				{"Или попробуйте наш "}
				<Link
					href="#"
					sx={{
						color: theme.palette.purple.main,
						textUnderlinePosition: "under",
						textDecorationColor: theme.palette.purple.main,
					}}
				>
          бесплатный план
				</Link>
			</Typography>
			<Typography
				sx={{
					mt: upMd ? "60px" : "70px",
					fontSize: isMobile ? "36px" : "24px",
					fontWeight: "500",
				}}
			>
        Наши продукты
			</Typography>

			{upMd ? <WideTemplCard sx={{ marginTop: "55px" }} /> : <TemplCardPhoneLight />}
		</SectionWrapper>
	)
}
