import { CartData, Discount, PrivilegeCartData, Tariff, TariffCartData, applyCartDiscount, applyLoyaltyDiscount, applyPrivilegeDiscounts, applyServiceDiscounts } from "@frontend/kitui"


export function calcCart(tariffs: Tariff[], discounts: Discount[], purchasesAmount: number, isUserNko?: boolean): CartData {
	const cartData: CartData = {
		services: [],
		priceBeforeDiscounts: 0,
		priceAfterDiscounts: 0,
		itemCount: 0,
		appliedCartPurchasesDiscount: null,
		appliedLoyaltyDiscount: null,
		allAppliedDiscounts: [],
	}

	tariffs.forEach(tariff => {
		let serviceData = cartData.services.find(service => service.serviceKey === tariff.privileges[0].serviceKey)
		if (!serviceData) {
			serviceData = {
				serviceKey: tariff.privileges[0].serviceKey,
				tariffs: [],
				price: 0,
				appliedServiceDiscount: null,
			}
			cartData.services.push(serviceData)
		}

		const tariffCartData: TariffCartData = {
			price: tariff.price ?? 0,
			isCustom: tariff.isCustom,
			privileges: [],
			id: tariff._id,
			name: tariff.name,
		}
		serviceData.tariffs.push(tariffCartData)

		tariff.privileges.forEach(privilege => {
			const privilegePrice = privilege.amount * privilege.price

			if (!tariff.price) tariffCartData.price += privilegePrice

			const privilegeCartData: PrivilegeCartData = {
				serviceKey: privilege.serviceKey,
				privilegeId: privilege.privilegeId,
				description: privilege.description,
				price: privilegePrice,
				appliedPrivilegeDiscount: null,
			}

			tariffCartData.privileges.push(privilegeCartData)
			cartData.priceAfterDiscounts += privilegePrice
			cartData.itemCount++
		})

		cartData.priceBeforeDiscounts += tariffCartData.price
		serviceData.price += tariffCartData.price
	})

	const nkoDiscount = findNkoDiscount(discounts)
	if (isUserNko && nkoDiscount) {
		applyNkoDiscount(cartData, nkoDiscount)
	} else {
		applyPrivilegeDiscounts(cartData, discounts)
		applyServiceDiscounts(cartData, discounts)
		applyCartDiscount(cartData, discounts)
		applyLoyaltyDiscount(cartData, discounts, purchasesAmount)
	}

	cartData.allAppliedDiscounts = Array.from(new Set(cartData.allAppliedDiscounts))

	return cartData
}

function applyNkoDiscount(cartData: CartData, discount: Discount) {
	cartData.priceAfterDiscounts *= discount.Target.Factor
	cartData.allAppliedDiscounts.push(discount)
}

export function findNkoDiscount(discounts: Discount[]): Discount | null {
	const applicableDiscounts = discounts.filter(discount => discount.Condition.UserType === "nko")

	if (!applicableDiscounts.length) return null

	const maxValueDiscount = applicableDiscounts.reduce((prev, current) => {
		return current.Condition.CartPurchasesAmount > prev.Condition.CartPurchasesAmount ? current : prev
	})

	return maxValueDiscount
}
